instrumenttools.Guitar
======================

.. abjad-lineage:: abjad.tools.instrumenttools.Guitar.Guitar.Guitar

.. autoclass:: abjad.tools.instrumenttools.Guitar.Guitar.Guitar
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.instrumenttools.Guitar.Guitar.Guitar.default_instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Guitar.Guitar.Guitar.default_short_instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Guitar.Guitar.Guitar.effective_context
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Guitar.Guitar.Guitar.interval_of_transposition
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Guitar.Guitar.Guitar.is_primary_instrument
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Guitar.Guitar.Guitar.is_secondary_instrument
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Guitar.Guitar.Guitar.is_transposing
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Guitar.Guitar.Guitar.lilypond_format
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Guitar.Guitar.Guitar.start_component
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Guitar.Guitar.Guitar.storage_format
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Guitar.Guitar.Guitar.target_context
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Guitar.Guitar.Guitar.traditional_pitch_range
   :noindex:

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.instrumenttools.Guitar.Guitar.Guitar.all_clefs
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Guitar.Guitar.Guitar.instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Guitar.Guitar.Guitar.instrument_name_markup
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Guitar.Guitar.Guitar.pitch_range
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Guitar.Guitar.Guitar.primary_clefs
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Guitar.Guitar.Guitar.short_instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Guitar.Guitar.Guitar.short_instrument_name_markup
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Guitar.Guitar.Guitar.sounding_pitch_of_fingered_middle_c
   :noindex:

Methods
-------

.. automethod:: abjad.tools.instrumenttools.Guitar.Guitar.Guitar.attach
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Guitar.Guitar.Guitar.detach
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Guitar.Guitar.Guitar.get_default_performer_name
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Guitar.Guitar.Guitar.get_performer_names
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.instrumenttools.Guitar.Guitar.Guitar.__call__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Guitar.Guitar.Guitar.__delattr__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Guitar.Guitar.Guitar.__eq__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Guitar.Guitar.Guitar.__ge__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Guitar.Guitar.Guitar.__gt__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Guitar.Guitar.Guitar.__hash__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Guitar.Guitar.Guitar.__le__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Guitar.Guitar.Guitar.__lt__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Guitar.Guitar.Guitar.__ne__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Guitar.Guitar.Guitar.__repr__
   :noindex:
